@@ -5,10 +5,10 @@ function(object, ...){
    J <- length(Hi)
    m <- object$m
    I.labels <- object$I.labels
-   summary.matrix <- matrix(0,nrow=J,ncol=9)
-   dimnames(summary.matrix) <- list(I.labels,c("ItemH","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","zmax","#zsig"))
+   summary.matrix <- matrix(0,nrow=J,ncol=10)
+   dimnames(summary.matrix) <- list(I.labels,c("ItemH","#ac","#vi","#vi/#ac","maxvi","sum","sum/#ac","zmax","#zsig","crit"))
    summary.matrix[,1] <- round(Hi,2)
-   rvm <- (m-1)*(m-1)+2
+   rvm <- (m-1)*(m-1)+1
    k <- 0; i <- 0; j <- 0
    for(i in 1:(J-1)){for(j in (i+1):J){
      k <- k+1
@@ -21,6 +21,18 @@ function(object, ...){
    }}
    summary.matrix[,4] <- summary.matrix[,3]/summary.matrix[,2]
    summary.matrix[,7] <- summary.matrix[,6]/summary.matrix[,2]
-   return(round(summary.matrix,2))
+   Crit <- 50 * (.30 - summary.matrix[,1]) + 
+           sqrt(summary.matrix[,3]) + 
+           100 * summary.matrix[,4]  + 
+           100 * summary.matrix[,5]  + 
+           10 * sqrt(summary.matrix[,6]) + 
+           1000 * summary.matrix[,7]  + 
+           5 * summary.matrix[,8]  + 
+           10 * sqrt(summary.matrix[,9])  + 
+           100 * summary.matrix[,9]/summary.matrix[,2] 
+   Crit[summary.matrix[,3]==0] <- 0
+   summary.matrix[,10] <- floor(Crit)
+   summary.matrix[,c(1:6,8:10)] <- round(summary.matrix[,c(1:6,8:10)],2)
+   summary.matrix[,c(7)] <- round(summary.matrix[,c(7)],4)
+   return(summary.matrix)
 }
-
